var NAVTREEINDEX0 =
{
"Spatial_searching_2Distance_8h-example.html":[4,1],
"Spatial_searching_2Point_8h-example.html":[4,0],
"Spatial_searching_2circular_query_8cpp-example.html":[4,2],
"Spatial_searching_2distance_browsing_8cpp-example.html":[4,3],
"Spatial_searching_2fuzzy_range_query_8cpp-example.html":[4,4],
"Spatial_searching_2general_neighbor_searching_8cpp-example.html":[4,5],
"Spatial_searching_2iso_rectangle_2_query_8cpp-example.html":[4,6],
"Spatial_searching_2iso_rectangle_2_query_projection_8cpp-example.html":[4,7],
"Spatial_searching_2nearest_neighbor_searching_8cpp-example.html":[4,8],
"Spatial_searching_2parallel_kdtree_8cpp-example.html":[4,21],
"Spatial_searching_2searching_polyhedron_vertices_8cpp-example.html":[4,11],
"Spatial_searching_2searching_sphere_orthogonally_8cpp-example.html":[4,20],
"Spatial_searching_2searching_surface_mesh_vertices_8cpp-example.html":[4,10],
"Spatial_searching_2searching_triangulation_vertices_8cpp-example.html":[4,12],
"Spatial_searching_2searching_with_circular_query_8cpp-example.html":[4,9],
"Spatial_searching_2searching_with_point_with_info_8cpp-example.html":[4,13],
"Spatial_searching_2searching_with_point_with_info_inplace_8cpp-example.html":[4,14],
"Spatial_searching_2searching_with_point_with_info_pmap_8cpp-example.html":[4,15],
"Spatial_searching_2splitter_worst_cases_8cpp-example.html":[4,19],
"Spatial_searching_2user_defined_point_and_distance_8cpp-example.html":[4,16],
"Spatial_searching_2using_fair_splitting_rule_8cpp-example.html":[4,17],
"Spatial_searching_2weighted_Minkowski_distance_8cpp-example.html":[4,18],
"annotated.html":[3],
"citelist.html":[2],
"classCGAL_1_1Distance__adapter.html":[1,0,4,3],
"classCGAL_1_1Distance__adapter.html#a1e8833285d81f871a3ce7b73be93fd3d":[1,0,4,3,0],
"classCGAL_1_1Distance__adapter.html#a5a4d314c40dda35373ea1062abd0186a":[1,0,4,3,3],
"classCGAL_1_1Distance__adapter.html#a74dcd35f9373cbd27c33138e55a5148e":[1,0,4,3,4],
"classCGAL_1_1Distance__adapter.html#a763da96f2a8ee88d74780964df59b09c":[1,0,4,3,1],
"classCGAL_1_1Distance__adapter.html#a9435231e0d6a745466edc27d46fad148":[1,0,4,3,2],
"classCGAL_1_1Euclidean__distance.html":[1,0,4,0],
"classCGAL_1_1Euclidean__distance.html#a0c00f3a6987f2a9a7b2a46825bb496e6":[1,0,4,0,2],
"classCGAL_1_1Euclidean__distance.html#a46ce687ec798ca7b33ed88151d7176de":[1,0,4,0,9],
"classCGAL_1_1Euclidean__distance.html#a48ca155a8b9574f5ebd21bd5533fb843":[1,0,4,0,1],
"classCGAL_1_1Euclidean__distance.html#a731005188fcdf6c5514448fc540ede6b":[1,0,4,0,10],
"classCGAL_1_1Euclidean__distance.html#a7412c41ee3a85b5065201e9f8bdf562e":[1,0,4,0,3],
"classCGAL_1_1Euclidean__distance.html#a980887d3b78c726fa648812269de226b":[1,0,4,0,7],
"classCGAL_1_1Euclidean__distance.html#a9911577e27beb00546c3dcaffa608ec5":[1,0,4,0,8],
"classCGAL_1_1Euclidean__distance.html#a9b534f360ca26151be0b33666622b6e8":[1,0,4,0,12],
"classCGAL_1_1Euclidean__distance.html#abe782f9ba4ce8929fcee2f3d7e5cabf1":[1,0,4,0,6],
"classCGAL_1_1Euclidean__distance.html#abe84667ca8337fed2c08eb6e1dad3751":[1,0,4,0,11],
"classCGAL_1_1Euclidean__distance.html#ad11686ecf6f6e2888d3979f87e23de3d":[1,0,4,0,13],
"classCGAL_1_1Euclidean__distance.html#ad9092038dcdb236e8b6fa5a3d7ea44fd":[1,0,4,0,5],
"classCGAL_1_1Euclidean__distance.html#ae53cc0d7e5ec6e8857d64570bf4ec5c9":[1,0,4,0,4],
"classCGAL_1_1Euclidean__distance.html#af379307b43d8660aa3ad34ab61e432e1":[1,0,4,0,14],
"classCGAL_1_1Euclidean__distance.html#af44518d66c58815bf2a68cfabbcc4140":[1,0,4,0,0],
"classCGAL_1_1Euclidean__distance__sphere__point.html":[1,0,4,1],
"classCGAL_1_1Euclidean__distance__sphere__point.html#a1f5de1466a4108a7d85cc1f8f56d9924":[1,0,4,1,8],
"classCGAL_1_1Euclidean__distance__sphere__point.html#a254874acb59c8bd6857bd79f87ec77ab":[1,0,4,1,5],
"classCGAL_1_1Euclidean__distance__sphere__point.html#a489a6c69fec1816375cfaad722711df0":[1,0,4,1,2],
"classCGAL_1_1Euclidean__distance__sphere__point.html#a9a53176a613f2eb5d70e50238a44c893":[1,0,4,1,7],
"classCGAL_1_1Euclidean__distance__sphere__point.html#a9fd6c907cebb22a2f42a60f0ac513bb8":[1,0,4,1,3],
"classCGAL_1_1Euclidean__distance__sphere__point.html#aabc7c62f18c9ed705a8b6657e2f7e448":[1,0,4,1,0],
"classCGAL_1_1Euclidean__distance__sphere__point.html#ab9409361f7ed24300b069cc852074bc3":[1,0,4,1,4],
"classCGAL_1_1Euclidean__distance__sphere__point.html#ad06a3349031cb081ad30a435ed7282d0":[1,0,4,1,1],
"classCGAL_1_1Euclidean__distance__sphere__point.html#aede7b77d8898e4ea019cba873f6d92e3":[1,0,4,1,9],
"classCGAL_1_1Euclidean__distance__sphere__point.html#af96287115e78e54a34ed6c15c6f1ccf0":[1,0,4,1,6],
"classCGAL_1_1Fair.html":[1,0,5,0],
"classCGAL_1_1Fair.html#a6adb4a55ddda826646db08f458d0d4fa":[1,0,5,0,1],
"classCGAL_1_1Fair.html#a83fa092234f53bda0c223bf058209a22":[1,0,5,0,2],
"classCGAL_1_1Fair.html#ab3854252f562f68025b16231b4539a1d":[1,0,5,0,0],
"classCGAL_1_1Fuzzy__iso__box.html":[1,0,2,0],
"classCGAL_1_1Fuzzy__iso__box.html#a0c98189b31a1de48e0618c88c05ca5c6":[1,0,2,0,5],
"classCGAL_1_1Fuzzy__iso__box.html#a4e772654ab65bb510353776f1d13bdf8":[1,0,2,0,1],
"classCGAL_1_1Fuzzy__iso__box.html#a72380a4509f01cb5c58e51932b2c3ca3":[1,0,2,0,2],
"classCGAL_1_1Fuzzy__iso__box.html#a7729dea7f4d3257744af9e8359b2473b":[1,0,2,0,7],
"classCGAL_1_1Fuzzy__iso__box.html#a8f7669d4adf5d37bf3ae08c18820d55d":[1,0,2,0,4],
"classCGAL_1_1Fuzzy__iso__box.html#aa1481713530526bc45530b36ed551f12":[1,0,2,0,0],
"classCGAL_1_1Fuzzy__iso__box.html#ac8c45b12eb511e760cc485e2a79653c6":[1,0,2,0,3],
"classCGAL_1_1Fuzzy__iso__box.html#ad2615c4b7747458b9dadd425c39b0a3c":[1,0,2,0,6],
"classCGAL_1_1Fuzzy__iso__box.html#aec24e116684685ee5dabfae88d2d5c7b":[1,0,2,0,8],
"classCGAL_1_1Fuzzy__sphere.html":[1,0,2,1],
"classCGAL_1_1Fuzzy__sphere.html#a3d0b4e60a8356dd5bda59bdb28a84e68":[1,0,2,1,3],
"classCGAL_1_1Fuzzy__sphere.html#a62283016c5b2ddd9983e5387adb188cc":[1,0,2,1,7],
"classCGAL_1_1Fuzzy__sphere.html#a8c179f9c34dc2a8a50092f14894830d6":[1,0,2,1,4],
"classCGAL_1_1Fuzzy__sphere.html#a91528744d0c24957897042b5219e6b84":[1,0,2,1,1],
"classCGAL_1_1Fuzzy__sphere.html#aa4941fcecb245023039e3a134c662351":[1,0,2,1,0],
"classCGAL_1_1Fuzzy__sphere.html#aa4f26fb4d9b3dc5581ce6fbfab3eaaf8":[1,0,2,1,5],
"classCGAL_1_1Fuzzy__sphere.html#acea3f4d973550293f05709f8eafef8f2":[1,0,2,1,2],
"classCGAL_1_1Fuzzy__sphere.html#ad5a637743b3e77049dfb6d58a035528b":[1,0,2,1,8],
"classCGAL_1_1Fuzzy__sphere.html#aeda0ae94d34661415e51598c0716aaf7":[1,0,2,1,6],
"classCGAL_1_1Incremental__neighbor__search.html":[1,0,1,0],
"classCGAL_1_1Incremental__neighbor__search.html#a036f39a9a4ad0f819881ee6806f50587":[1,0,1,0,1],
"classCGAL_1_1Incremental__neighbor__search.html#a05a7ed976ee9bd1dcff5a4234dee245d":[1,0,1,0,3],
"classCGAL_1_1Incremental__neighbor__search.html#a0665754c2ff227bc2c8eb25aa768d2ef":[1,0,1,0,10],
"classCGAL_1_1Incremental__neighbor__search.html#a40ec01e9501d6ddecb707513dc3e50c9":[1,0,1,0,5],
"classCGAL_1_1Incremental__neighbor__search.html#a86026d7f97a081689153f03bb4d5e243":[1,0,1,0,0],
"classCGAL_1_1Incremental__neighbor__search.html#a95b6ca796917c8bf0aff0e7d569770f2":[1,0,1,0,4],
"classCGAL_1_1Incremental__neighbor__search.html#a981ff4079af3a997f7beed1a0f447636":[1,0,1,0,7],
"classCGAL_1_1Incremental__neighbor__search.html#a99a6fe1646a57a68690bfeb2aa54d70f":[1,0,1,0,2],
"classCGAL_1_1Incremental__neighbor__search.html#ab36f18e8715a85c9e9bf8e092b8f5637":[1,0,1,0,6],
"classCGAL_1_1Incremental__neighbor__search.html#ac886e92b85a738dfb364153bf4fa9478":[1,0,1,0,9],
"classCGAL_1_1Incremental__neighbor__search.html#acd689c93330cfbeb194857efae017ccd":[1,0,1,0,8],
"classCGAL_1_1K__neighbor__search.html":[1,0,1,1],
"classCGAL_1_1K__neighbor__search.html#a05bfb7d698b467b4ef301052d7e5cc4d":[1,0,1,1,7],
"classCGAL_1_1K__neighbor__search.html#a29f01eff6f2705912f0834945e401e2c":[1,0,1,1,8],
"classCGAL_1_1K__neighbor__search.html#a374907e3a4b83e3cdbedf082c54ee1ad":[1,0,1,1,10],
"classCGAL_1_1K__neighbor__search.html#a3b06c8cef57e8bab082134470343c7e2":[1,0,1,1,6],
"classCGAL_1_1K__neighbor__search.html#a788fb89a2e01dec4bb2463ac209ac713":[1,0,1,1,0],
"classCGAL_1_1K__neighbor__search.html#a7b3a10ce2d56e1a4f33710ddf727f1f6":[1,0,1,1,4],
"classCGAL_1_1K__neighbor__search.html#aacb51a07608a32d890241d420929be4f":[1,0,1,1,5],
"classCGAL_1_1K__neighbor__search.html#aba164642ca7ff58b8fff33851b5266d9":[1,0,1,1,3],
"classCGAL_1_1K__neighbor__search.html#ad26a3d2c9da3788a3bd087b1b05ad7eb":[1,0,1,1,2],
"classCGAL_1_1K__neighbor__search.html#ae1998c0714c5d18ccc31165f7273133a":[1,0,1,1,9],
"classCGAL_1_1K__neighbor__search.html#affb644e1c094596eb97f10a32834c14a":[1,0,1,1,1],
"classCGAL_1_1Kd__tree.html":[1,0,1,2],
"classCGAL_1_1Kd__tree.html#a0a8319d9f6ab08f9251311b335ea7934":[1,0,1,2,22],
"classCGAL_1_1Kd__tree.html#a0f88a1fe143f074b5bbe1db3379a89cf":[1,0,1,2,1],
"classCGAL_1_1Kd__tree.html#a149dfb00eab32734009e1c0f147f8394":[1,0,1,2,6],
"classCGAL_1_1Kd__tree.html#a34253aa1beeada9004291e373f53ac4f":[1,0,1,2,7],
"classCGAL_1_1Kd__tree.html#a38fc9a612a2080b0ee6c8f7c8f00c7bc":[1,0,1,2,2],
"classCGAL_1_1Kd__tree.html#a3d1fa857902da7a89f22deeb38bca37e":[1,0,1,2,11],
"classCGAL_1_1Kd__tree.html#a44886e60ae72715660155db4c2886a00":[1,0,1,2,13],
"classCGAL_1_1Kd__tree.html#a47161743bac7e2fd6a8cb110a0b05115":[1,0,1,2,3],
"classCGAL_1_1Kd__tree.html#a49a70b7472c9eeeff2994503c7e5a119":[1,0,1,2,0],
"classCGAL_1_1Kd__tree.html#a4bbdcd5d67d328501c80d90a8921e937":[1,0,1,2,31],
"classCGAL_1_1Kd__tree.html#a4da164259c231356c66bdd2f2c430737":[1,0,1,2,20],
"classCGAL_1_1Kd__tree.html#a4e760af1ae3da968dec45b378db207fc":[1,0,1,2,26],
"classCGAL_1_1Kd__tree.html#a7105130c445c8383bf529640acc89149":[1,0,1,2,28],
"classCGAL_1_1Kd__tree.html#a7918b28bcc630e9235092ba4b4c3714b":[1,0,1,2,12],
"classCGAL_1_1Kd__tree.html#a7b905fc78025678db12eb5888abd464d":[1,0,1,2,4],
"classCGAL_1_1Kd__tree.html#a7d752fdbf38d25b98d0896fa432cc34b":[1,0,1,2,17],
"classCGAL_1_1Kd__tree.html#a8559dbe4d7136fbc8ebab5ee290cbe06":[1,0,1,2,14],
"classCGAL_1_1Kd__tree.html#a88253eeef4d5b9271c746c2db241c49d":[1,0,1,2,25],
"classCGAL_1_1Kd__tree.html#a8c3a4d88ec64872f004a2a2650fd0ba8":[1,0,1,2,8],
"classCGAL_1_1Kd__tree.html#a94918b23936d6c942ce87eea4c104cda":[1,0,1,2,30],
"classCGAL_1_1Kd__tree.html#aafa6142f78b1d6c32fc9b2f324bf2a7f":[1,0,1,2,10],
"classCGAL_1_1Kd__tree.html#abbd8518e711a6c90ac42970b086ac426":[1,0,1,2,15],
"classCGAL_1_1Kd__tree.html#abf03f9584a80aa5ac5340ef0a9189719":[1,0,1,2,29],
"classCGAL_1_1Kd__tree.html#ac1fd68b1289455242f1f9ca8663e83b8":[1,0,1,2,24],
"classCGAL_1_1Kd__tree.html#ac327e1f15dde058d1fc20b69c42d410d":[1,0,1,2,21],
"classCGAL_1_1Kd__tree.html#ac37f7df66ed45c5c803fa691b54fb178":[1,0,1,2,16],
"classCGAL_1_1Kd__tree.html#ad1f452a7c7d482cc6f5f522524b19935":[1,0,1,2,19],
"classCGAL_1_1Kd__tree.html#ae529eef8ba4e1eba835c703f93e6bc6e":[1,0,1,2,9],
"classCGAL_1_1Kd__tree.html#ae85b8f9ea700cc73db0dba026bb04d2e":[1,0,1,2,23],
"classCGAL_1_1Kd__tree.html#aee342550f8e06310f1ae3deaab135bab":[1,0,1,2,27],
"classCGAL_1_1Kd__tree.html#aee46b67bd36045213ae5d8f98d355ea0":[1,0,1,2,18],
"classCGAL_1_1Kd__tree.html#afb279f4ebddcfbf03ab415aa89f48352":[1,0,1,2,5],
"classCGAL_1_1Kd__tree__internal__node.html":[1,0,6,2],
"classCGAL_1_1Kd__tree__internal__node.html#a4b3e1b5dc5c9ca06e6c88efd6cb12444":[1,0,6,2,1],
"classCGAL_1_1Kd__tree__internal__node.html#a4e7b72fc270bf7134733d3d92fbf9303":[1,0,6,2,2],
"classCGAL_1_1Kd__tree__internal__node.html#a5958322cc1e1534cecc455b20a1ae1fe":[1,0,6,2,9],
"classCGAL_1_1Kd__tree__internal__node.html#a61f13c1ac5e8e4ebd066c6daebee7b5a":[1,0,6,2,11],
"classCGAL_1_1Kd__tree__internal__node.html#a76298715d6efa9a37a61975d3107c0ce":[1,0,6,2,7],
"classCGAL_1_1Kd__tree__internal__node.html#a8bdc96cd12d37a74dc311ee03b8855bc":[1,0,6,2,10],
"classCGAL_1_1Kd__tree__internal__node.html#aa71ee56263547d439be915d3cf00e945":[1,0,6,2,6],
"classCGAL_1_1Kd__tree__internal__node.html#aae0999483f6a9b9fc5d4b21869a72390":[1,0,6,2,3],
"classCGAL_1_1Kd__tree__internal__node.html#ab75235414c17064cf3dbb85e5fe19083":[1,0,6,2,4],
"classCGAL_1_1Kd__tree__internal__node.html#ac4cebdd0b3cf17dd6496656f8396d67a":[1,0,6,2,12],
"classCGAL_1_1Kd__tree__internal__node.html#ac5c56bae7fed642c28cce9fee248cc6f":[1,0,6,2,0],
"classCGAL_1_1Kd__tree__internal__node.html#acb899624cf266ee4b0e28489927c97cf":[1,0,6,2,8],
"classCGAL_1_1Kd__tree__internal__node.html#afd38f6e8d629538877dc78926ee4dfc7":[1,0,6,2,5],
"classCGAL_1_1Kd__tree__leaf__node.html":[1,0,6,1],
"classCGAL_1_1Kd__tree__leaf__node.html#a0816b89c802def831144c86c5f1c427a":[1,0,6,1,1],
"classCGAL_1_1Kd__tree__leaf__node.html#a430e71afc9d215ced7beb5206b597f44":[1,0,6,1,2],
"classCGAL_1_1Kd__tree__leaf__node.html#a4db1ef8f0afd603b98ec5fbb58739de0":[1,0,6,1,3],
"classCGAL_1_1Kd__tree__leaf__node.html#adeb327400c32d404c4ea9189b293fc00":[1,0,6,1,0],
"classCGAL_1_1Kd__tree__node.html":[1,0,6,0],
"classCGAL_1_1Kd__tree__node.html#a054756c9310f75726515fb2602961798":[1,0,6,0,4],
"classCGAL_1_1Kd__tree__node.html#a087bad7474be5f8e35d7ed07a39edb68":[1,0,6,0,1],
"classCGAL_1_1Kd__tree__node.html#a52afb420a9c72fd8ef256b16503636a8":[1,0,6,0,2],
"classCGAL_1_1Kd__tree__node.html#a8009f0fe9aebd602296f8d2a2806ea0f":[1,0,6,0,3],
"classCGAL_1_1Kd__tree__node.html#af708d4e7b49b7c3c29843c2cbbe58855":[1,0,6,0,0],
"classCGAL_1_1Kd__tree__rectangle.html":[1,0,6,3],
"classCGAL_1_1Kd__tree__rectangle.html#a00e9a463d880082617ea24e76bca89f4":[1,0,6,3,2],
"classCGAL_1_1Kd__tree__rectangle.html#a469a942d0ed5e9dc86e43ccb363f7bd7":[1,0,6,3,10],
"classCGAL_1_1Kd__tree__rectangle.html#a48b6313e077e95a7ee37f0a83b05933d":[1,0,6,3,11],
"classCGAL_1_1Kd__tree__rectangle.html#a7e2867b92e3f31a934c485b4a80f0156":[1,0,6,3,5],
"classCGAL_1_1Kd__tree__rectangle.html#aaccf4291dc65acc49af3585ced689de7":[1,0,6,3,7],
"classCGAL_1_1Kd__tree__rectangle.html#aadc76a158fd0c7c128d278e1957966d9":[1,0,6,3,4],
"classCGAL_1_1Kd__tree__rectangle.html#ac23671b8977b090392b945483d788389":[1,0,6,3,8],
"classCGAL_1_1Kd__tree__rectangle.html#ac50f4cb6849b4ff6fc1eff08d30cb375":[1,0,6,3,6],
"classCGAL_1_1Kd__tree__rectangle.html#ac549252f23abc4d3e418374e60de0f42":[1,0,6,3,3],
"classCGAL_1_1Kd__tree__rectangle.html#ad1ab8452a8703a2d5a86756b567eed15":[1,0,6,3,9],
"classCGAL_1_1Kd__tree__rectangle.html#adbb671cc891746395748a937fda10260":[1,0,6,3,1],
"classCGAL_1_1Kd__tree__rectangle.html#aed9240e15282a7f9b47255b506d701ff":[1,0,6,3,0],
"classCGAL_1_1Kd__tree__rectangle.html#af32a4514cc4b83560bff120b8c3054f0":[1,0,6,3,12],
"classCGAL_1_1Manhattan__distance__iso__box__point.html":[1,0,4,2],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a086999aaaffc45005f7646750b49cb4d":[1,0,4,2,3],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a1d6e589a0eb5048fe4422d82e17163b9":[1,0,4,2,5],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a29035b4c250f9f87f98c298e4bf5e216":[1,0,4,2,6],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a492c615f0b765280f35f06132fc67904":[1,0,4,2,7],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a5f1021d6f15ff1364d5482e760180409":[1,0,4,2,1],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a6c4cc5e886b30623f5f71f75761d4c85":[1,0,4,2,8],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#a77db67712228846bbaaace47a9751c86":[1,0,4,2,0],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#ab8fcc62162ddbcb9618b420145808eb4":[1,0,4,2,4],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#ad5f8228bdc51066bf3087d257da78bd4":[1,0,4,2,9],
"classCGAL_1_1Manhattan__distance__iso__box__point.html#afe1ccd6dcc314b476ca6ed65160e969a":[1,0,4,2,2],
"classCGAL_1_1Median__of__max__spread.html":[1,0,5,1],
"classCGAL_1_1Median__of__max__spread.html#a8a8fb631d2faeec304b64819261ad948":[1,0,5,1,1],
"classCGAL_1_1Median__of__max__spread.html#a938fa2463a54f6c01af6e97ab4b90607":[1,0,5,1,0],
"classCGAL_1_1Median__of__rectangle.html":[1,0,5,2],
"classCGAL_1_1Median__of__rectangle.html#a769e084428eb174eddf07ff375b767e6":[1,0,5,2,1],
"classCGAL_1_1Median__of__rectangle.html#a797971cadc3137449b0e415dc8403cbc":[1,0,5,2,0],
"classCGAL_1_1Midpoint__of__max__spread.html":[1,0,5,3],
"classCGAL_1_1Midpoint__of__max__spread.html#a499e339e23ccc724af2afab14625198f":[1,0,5,3,1],
"classCGAL_1_1Midpoint__of__max__spread.html#a7000f0d1646706a6bb6b7986bf23aad5":[1,0,5,3,0],
"classCGAL_1_1Midpoint__of__rectangle.html":[1,0,5,4],
"classCGAL_1_1Midpoint__of__rectangle.html#a3fc40c58fa0b606b355fe774b4885835":[1,0,5,4,0],
"classCGAL_1_1Midpoint__of__rectangle.html#a7a4372ccbdebcd951b255de330f3b169":[1,0,5,4,1],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html":[1,0,1,3],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a0936890bf2f934a7079f3f8eb2319c4d":[1,0,1,3,6],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a09837c563d1fb692167d7dec9659b758":[1,0,1,3,10],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a4deff47bb517da4648ab9978a4b10264":[1,0,1,3,2],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a4e02c26f014fb132bc26e095b92f5faf":[1,0,1,3,9],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a51d7b6c6efd4d6bb6128ab1b5d030bb1":[1,0,1,3,5],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a714cfa0ed7729fa8ddec021a4f2e3dbc":[1,0,1,3,3],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a7bd16edfd4b58c8147097a99715770a3":[1,0,1,3,0],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a811808814cf3f6990d4fc0c8b4014bbd":[1,0,1,3,8],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#a883d518b2e5a2024994f3a4a419aec61":[1,0,1,3,4],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#aba8092581c61dba907b6d58ad44d4092":[1,0,1,3,1],
"classCGAL_1_1Orthogonal__incremental__neighbor__search.html#ad62fd251c29f251c185bf6d7a17d39ed":[1,0,1,3,7],
"classCGAL_1_1Orthogonal__k__neighbor__search.html":[1,0,1,4],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a0e4a5b6dccd7353b30a76a2be0a314fe":[1,0,1,4,5],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a18f8765a4384477b4acfee1d15938939":[1,0,1,4,7],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a25bde1160d0c7784f04ccd2a9e9019f9":[1,0,1,4,6],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a40e40a2656f3f60512fe8507c6d1a53c":[1,0,1,4,3],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a51a39f6c69f4139e349650e2b6475e6b":[1,0,1,4,8],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a5ca43e58a7b8901ec4a869584dcf523b":[1,0,1,4,2],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#a77350b00a1efb4f1840ca5aedac4486b":[1,0,1,4,4],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#aa171cea6d4ecc9168a324e3afafef57d":[1,0,1,4,0],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#aad851ba99ef06a73ec097333c3714ca3":[1,0,1,4,10],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#ac509e09598b45d4b4e20a0a0024f6649":[1,0,1,4,9],
"classCGAL_1_1Orthogonal__k__neighbor__search.html#ac79496b2564b6d0cf863e50dbd2c4714":[1,0,1,4,1],
"classCGAL_1_1Plane__separator.html":[1,0,6,4],
"classCGAL_1_1Plane__separator.html#a6b9b0f812c4524f14fa074fdd2108547":[1,0,6,4,3],
"classCGAL_1_1Plane__separator.html#a8dc5b04272d8e0750eea9f798f2d4a68":[1,0,6,4,6],
"classCGAL_1_1Plane__separator.html#aa7796f90455f7403e7819c52089b3a49":[1,0,6,4,4],
"classCGAL_1_1Plane__separator.html#ab5b517a7ae00e0726a0e972b33d92009":[1,0,6,4,2],
"classCGAL_1_1Plane__separator.html#ad7bc8e23ba3a3a632ac77edaa92c91b4":[1,0,6,4,5],
"classCGAL_1_1Plane__separator.html#addfa6896444730f6e4460742dd5b2328":[1,0,6,4,1],
"classCGAL_1_1Plane__separator.html#af14b2e23b5a6e8c8719062f2dad5fd94":[1,0,6,4,0],
"classCGAL_1_1Plane__separator.html#afc7700de0bbea2631ccc3dc82165ed01":[1,0,6,4,7],
"classCGAL_1_1Point__container.html":[1,0,6,5],
"classCGAL_1_1Point__container.html#a003598d5995d6a3f8d070a01628e6344":[1,0,6,5,23],
"classCGAL_1_1Point__container.html#a04fae170d9914cbc15f37304e659f300":[1,0,6,5,32],
"classCGAL_1_1Point__container.html#a09075efcb37c9e1ced3814ac69532aae":[1,0,6,5,13],
"classCGAL_1_1Point__container.html#a09615da9eb4dbb0c840be320d3a57d8c":[1,0,6,5,28],
"classCGAL_1_1Point__container.html#a0d1f63b6d2f5b0bea16c0ed7bf5c9304":[1,0,6,5,20],
"classCGAL_1_1Point__container.html#a12f8e59f564189e8d590c301b9f9d31d":[1,0,6,5,29],
"classCGAL_1_1Point__container.html#a22044adb30bec5438ce6de773c745784":[1,0,6,5,3],
"classCGAL_1_1Point__container.html#a22700f616acfcb466230d919a197f3b0":[1,0,6,5,5],
"classCGAL_1_1Point__container.html#a3d8eb7234328742934933f6c017e151b":[1,0,6,5,1],
"classCGAL_1_1Point__container.html#a44e4139e85208a1c616143c852b6d525":[1,0,6,5,19],
"classCGAL_1_1Point__container.html#a510c991ec32c1a64bafe8aeaf81e9698":[1,0,6,5,24],
"classCGAL_1_1Point__container.html#a511692230242c812950f8a4e9dc851dd":[1,0,6,5,16],
"classCGAL_1_1Point__container.html#a6238baa8a56c87a34699d5f9e78b38bc":[1,0,6,5,8],
"classCGAL_1_1Point__container.html#a74134c5ca23c545ac48dfdcc58b5e0e8":[1,0,6,5,21],
"classCGAL_1_1Point__container.html#a75897f0c5fc568e4f0ee1861a7e7253f":[1,0,6,5,6],
"classCGAL_1_1Point__container.html#a781f28e1b6b4d23a6aa5903e17ba6ff2":[1,0,6,5,7]
};
